@@ -339,7 +339,7 @@ class OssFilesPipeline(MediaPipeline):
         if kind =='html': 
             # 如果判断结果为html,大概率下载失败
             with suppress(NameError):   
-                logging.warning("下载文件为html,请确认是否下载成功")
+                logging.warning(f"下载文件为html,请确认是否下载成功,请求头:{str(Headers(request.headers, encoding='utf-8').to_unicode_dict())}")
                 return ''
             media_ext = '.'+kind if not kind.startswith(".") else kind
         # if self.ext_model :
